@@ -8,9 +8,14 @@ from dbt.logger import GLOBAL_LOGGER as logger
 from dbt.utils import DECIMALS
 from dbt.adapters.spark import __version__
 
-from TCLIService.ttypes import TOperationState as ThriftState
-from thrift.transport import THttpClient
-from pyhive import hive
+try:
+    from TCLIService.ttypes import TOperationState as ThriftState
+    from thrift.transport import THttpClient
+    from pyhive import hive
+except ImportError:
+    ThriftState = None
+    THttpClient = None
+    hive = None
 try:
     import pyodbc
 except ImportError:
@@ -88,6 +93,19 @@ class SparkCredentials(Credentials):
                 f" using {self.method} method to connect to Spark"
             )
 
+        if (
+            self.method == SparkConnectionMethod.HTTP or
+            self.method == SparkConnectionMethod.THRIFT
+        ) and not (
+            ThriftState and THttpClient and hive
+        ):
+            raise dbt.exceptions.RuntimeException(
+                f"{self.method} connection method requires "
+                "additional dependencies. \n"
+                "Install the additional required dependencies with "
+                "`pip install dbt-spark[PyHive]`"
+            )
+
     @property
     def type(self):
         return 'spark'
@@ -255,7 +273,7 @@ class SparkConnectionManager(SQLConnectionManager):
         connection.handle.cancel()
 
     @classmethod
-    def get_status(cls, cursor):
+    def get_response(cls, cursor):
         return 'OK'
 
     # No transactions on Spark....
@@ -383,7 +401,7 @@ class SparkConnectionManager(SQLConnectionManager):
                         msg += ', is your token valid?'
                     raise dbt.exceptions.FailedToConnectException(msg) from e
                 retryable_message = _is_retryable_error(e)
-                if retryable_message:
+                if retryable_message and creds.connect_retries > 0:
                     msg = (
                         f"Warning: {retryable_message}\n\tRetrying in "
                         f"{creds.connect_timeout} seconds "
